# Navigation Grid Visualization

A simple Python3 interface designed using Matplotlib to visualize high dimensional data. It's designed specifically for 2D navigation grid world, however the interface can also be used to visualize any kind of data that can be represented in a 2D grid.

## Usage
If you're curious what it can do:

### 1. View examples in the notebook
[Raster grid view](./navgridviews_raster.ipynb)

### 2. Play with it on Google Colab
[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/yrevar/navigation_vis/blob/master/navgridviews_raster.ipynb)
    

### 3. Play with it on MyBinder
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/yrevar/navigation_vis/master?urlpath=https%3A%2F%2Fgithub.com%2Fyrevar%2Fnavigation_vis%2Fblob%2Fmaster%2Fnavgridviews_raster.ipynb)
